@@ -13,9 +13,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.core.urlresolvers import reverse_lazy
 from django.core.validators import RegexValidator
-from django.utils.translation import ugettext_lazy as _
+from django.urls import reverse_lazy
+from django.utils.translation import gettext_lazy as _
 
 from horizon import forms
 
@@ -104,3 +104,12 @@ class EditDataBgpVpn(CommonData):
     def __init__(self, request, *args, **kwargs):
         super(EditDataBgpVpn, self).__init__(request, *args, **kwargs)
         self.action = 'update'
+
+
+class CreateNetworkAssociation(project_forms.CreateNetworkAssociation):
+    project_id = forms.CharField(widget=forms.HiddenInput())
+
+    def _set_params(self, data):
+        params = super(CreateNetworkAssociation, self)._set_params(data)
+        params['tenant_id'] = data['project_id']
+        return params
