@@ -15,10 +15,10 @@
 
 import logging
 
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.utils import html
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ungettext_lazy
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ngettext_lazy
 from horizon import exceptions
 from horizon import tables
 from openstack_dashboard import policy
@@ -32,15 +32,15 @@ LOG = logging.getLogger(__name__)
 class DeleteBgpvpn(policy.PolicyTargetMixin, tables.DeleteAction):
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(u"Delete BGPVPN",
-                              u"Delete BGPVPNs",
-                              count)
+        return ngettext_lazy(u"Delete BGPVPN",
+                             u"Delete BGPVPNs",
+                             count)
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(u"Deleted BGPVPN",
-                              u"Deleted BGPVPNs",
-                              count)
+        return ngettext_lazy(u"Deleted BGPVPN",
+                             u"Deleted BGPVPNs",
+                             count)
 
     def delete(self, request, obj_id):
         try:
@@ -64,12 +64,12 @@ class EditInfoBgpVpn(project_tables.EditInfoBgpVpn):
     url = "horizon:admin:bgpvpn:edit"
 
 
-class UpdateNetworkAssociations(project_tables.UpdateNetworkAssociations):
-    url = "horizon:admin:bgpvpn:update-associations"
+class CreateNetworkAssociation(project_tables.CreateNetworkAssociation):
+    url = "horizon:admin:bgpvpn:create-network-association"
 
 
-class UpdateRouterAssociations(project_tables.UpdateRouterAssociations):
-    url = "horizon:admin:bgpvpn:update-associations"
+class CreateRouterAssociation(project_tables.CreateRouterAssociation):
+    url = "horizon:admin:bgpvpn:create-router-association"
 
 
 def get_route_targets(bgpvpn):
@@ -96,26 +96,19 @@ def get_router_url(router):
     return instance
 
 
-class BgpvpnTable(tables.DataTable):
-    tenant_id = tables.Column("tenant_name", verbose_name=_("Project"))
-    name = tables.Column("name_or_id",
-                         verbose_name=_("Name"),
-                         link=("horizon:admin:bgpvpn:detail"))
-    type = tables.Column("type", verbose_name=_("Type"))
+class BgpvpnTable(project_tables.BgpvpnTable):
     route_targets = tables.Column(get_route_targets,
                                   verbose_name=_("Route Targets"))
     import_targets = tables.Column(get_import_targets,
                                    verbose_name=_("Import Targets"))
     export_targets = tables.Column(get_export_targets,
                                    verbose_name=_("Export Targets"))
-    networks = project_tables.NetworksColumn("networks",
-                                             verbose_name=_("Networks"))
-    routers = project_tables.RoutersColumn("routers",
-                                           verbose_name=_("Routers"))
 
     class Meta(object):
         table_actions = (CreateBgpVpn, DeleteBgpvpn)
         row_actions = (EditInfoBgpVpn,
-                       UpdateNetworkAssociations,
-                       UpdateRouterAssociations,
+                       CreateNetworkAssociation,
+                       CreateRouterAssociation,
                        DeleteBgpvpn)
+        columns = ("tenant_id", "name", "type", "route_targets",
+                   "import_targets", "export_targets", "networks", "routers")
