@@ -13,11 +13,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.utils import html
 from django.utils.http import urlencode
 from django.utils import safestring
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from horizon import tables
 
 
@@ -29,29 +29,23 @@ class EditInfoBgpVpn(tables.LinkAction):
     icon = "pencil"
 
 
-class UpdateNetworkAssociations(tables.LinkAction):
-    name = "update_network_associations"
-    verbose_name = _("Update Network Associations")
-    url = "horizon:project:bgpvpn:update-associations"
+class CreateNetworkAssociation(tables.LinkAction):
+    name = "create_network_association"
+    verbose_name = _("Create Network Association")
+    url = "horizon:project:bgpvpn:create-network-association"
+    classes = ("ajax-modal",)
+    icon = "pencil"
+
+
+class CreateRouterAssociation(tables.LinkAction):
+    name = "create_router_association"
+    verbose_name = _("Create Router Association")
+    url = "horizon:project:bgpvpn:create-router-association"
     classes = ("ajax-modal",)
     icon = "pencil"
 
     def get_link_url(self, bgpvpn):
-        step = 'update_bgpvpn_network'
-        base_url = reverse(self.url, args=[bgpvpn.id])
-        param = urlencode({"step": step})
-        return "?".join([base_url, param])
-
-
-class UpdateRouterAssociations(tables.LinkAction):
-    name = "update_router_associations"
-    verbose_name = _("Update Router Associations")
-    url = "horizon:project:bgpvpn:update-associations"
-    classes = ("ajax-modal",)
-    icon = "pencil"
-
-    def get_link_url(self, bgpvpn):
-        step = 'update_bgpvpn_router'
+        step = 'create_router_association'
         base_url = reverse(self.url, args=[bgpvpn.id])
         param = urlencode({"step": step})
         return "?".join([base_url, param])
@@ -93,5 +87,5 @@ class BgpvpnTable(tables.DataTable):
         name = "bgpvpns"
         verbose_name = _("BGPVPN")
         row_actions = (EditInfoBgpVpn,
-                       UpdateNetworkAssociations,
-                       UpdateRouterAssociations)
+                       CreateNetworkAssociation,
+                       CreateRouterAssociation)
