@@ -14,16 +14,16 @@
 #    under the License.
 import logging
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from horizon import exceptions
 from horizon import forms
 from horizon import workflows
 from openstack_dashboard import api
 
-LOG = logging.getLogger(__name__)
-
 from bgpvpn_dashboard.api import bgpvpn as bgpvpn_api
 
+LOG = logging.getLogger(__name__)
+
 
 class AddRouterParametersInfoAction(workflows.Action):
 
@@ -132,8 +132,8 @@ class RouterAssociation(workflows.Workflow):
         try:
             router_association = bgpvpn_api.router_association_create(
                 request, bgpvpn_id, router_id=router_id)
-        except Exception as e:
-            exceptions.handle(request, msg_error + ": %s" % str(e))
+        except Exception:
+            exceptions.handle(request, msg_error)
             return False
         if not context["with_parameters"]:
             return True
@@ -143,7 +143,7 @@ class RouterAssociation(workflows.Workflow):
                 request, bgpvpn_id, asso_id,
                 advertise_extra_routes=context['advertise_extra_routes'])
             return True
-        except exceptions as e:
+        except exceptions:
             bgpvpn_api.router_association_delete(request, asso_id, bgpvpn_id)
-            exceptions.handle(request, msg_error + ": %s" % str(e))
+            exceptions.handle(request, msg_error)
             return False
