@@ -15,17 +15,15 @@
 
 import abc
 import copy
-import six
 
-from neutron.db import api as db_api
+from neutron_lib.db import api as db_api
 
 from networking_bgpvpn.neutron.db import bgpvpn_db
 from networking_bgpvpn.neutron.extensions \
     import bgpvpn_routes_control as bgpvpn_rc
 
 
-@six.add_metaclass(abc.ABCMeta)
-class BGPVPNDriverBase(object):
+class BGPVPNDriverBase(metaclass=abc.ABCMeta):
     """BGPVPNDriver interface for driver
 
     That driver interface does not persist BGPVPN data in any database. The
@@ -61,7 +59,7 @@ class BGPVPNDriverBase(object):
         pass
 
     @abc.abstractmethod
-    def create_net_assoc(self, bgpvpn_id, network_association):
+    def create_net_assoc(self, context, bgpvpn_id, network_association):
         pass
 
     @abc.abstractmethod
@@ -93,8 +91,7 @@ class BGPVPNDriverBase(object):
         pass
 
 
-@six.add_metaclass(abc.ABCMeta)
-class BGPVPNDriverDBMixin(BGPVPNDriverBase):
+class BGPVPNDriverDBMixin(BGPVPNDriverBase, metaclass=abc.ABCMeta):
     """BGPVPNDriverDB Mixin to provision the database on behalf of the driver
 
     That driver interface persists BGPVPN data in its database and forwards
@@ -102,11 +99,11 @@ class BGPVPNDriverDBMixin(BGPVPNDriverBase):
     """
 
     def __init__(self, *args, **kwargs):
-        super(BGPVPNDriverDBMixin, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.bgpvpn_db = bgpvpn_db.BGPVPNPluginDb()
 
     def create_bgpvpn(self, context, bgpvpn):
-        with db_api.context_manager.writer.using(context):
+        with db_api.CONTEXT_WRITER.using(context):
             bgpvpn = self.bgpvpn_db.create_bgpvpn(
                 context, bgpvpn)
             self.create_bgpvpn_precommit(context, bgpvpn)
@@ -119,25 +116,25 @@ class BGPVPNDriverDBMixin(BGPVPNDriverBase):
     def get_bgpvpn(self, context, id, fields=None):
         return self.bgpvpn_db.get_bgpvpn(context, id, fields)
 
-    def update_bgpvpn(self, context, id, bgpvpn_delta):
+    def update_bgpvpn(self, context, id, bgpvpn):
         old_bgpvpn = self.get_bgpvpn(context, id)
-        with db_api.context_manager.writer.using(context):
+        with db_api.CONTEXT_WRITER.using(context):
             new_bgpvpn = copy.deepcopy(old_bgpvpn)
-            new_bgpvpn.update(bgpvpn_delta)
+            new_bgpvpn.update(bgpvpn)
             self.update_bgpvpn_precommit(context, old_bgpvpn, new_bgpvpn)
-            bgpvpn = self.bgpvpn_db.update_bgpvpn(context, id, bgpvpn_delta)
+            bgpvpn = self.bgpvpn_db.update_bgpvpn(context, id, bgpvpn)
         self.update_bgpvpn_postcommit(context, old_bgpvpn, bgpvpn)
         return bgpvpn
 
     def delete_bgpvpn(self, context, id):
-        with db_api.context_manager.writer.using(context):
+        with db_api.CONTEXT_WRITER.using(context):
             bgpvpn = self.bgpvpn_db.get_bgpvpn(context, id)
             self.delete_bgpvpn_precommit(context, bgpvpn)
             self.bgpvpn_db.delete_bgpvpn(context, id)
         self.delete_bgpvpn_postcommit(context, bgpvpn)
 
     def create_net_assoc(self, context, bgpvpn_id, network_association):
-        with db_api.context_manager.writer.using(context):
+        with db_api.CONTEXT_WRITER.using(context):
             assoc = self.bgpvpn_db.create_net_assoc(context,
                                                     bgpvpn_id,
                                                     network_association)
@@ -154,7 +151,7 @@ class BGPVPNDriverDBMixin(BGPVPNDriverBase):
                                              filters, fields)
 
     def delete_net_assoc(self, context, assoc_id, bgpvpn_id):
-        with db_api.context_manager.writer.using(context):
+        with db_api.CONTEXT_WRITER.using(context):
             net_assoc = self.bgpvpn_db.get_net_assoc(context,
                                                      assoc_id,
                                                      bgpvpn_id)
@@ -166,7 +163,7 @@ class BGPVPNDriverDBMixin(BGPVPNDriverBase):
         self.delete_net_assoc_postcommit(context, net_assoc)
 
     def create_router_assoc(self, context, bgpvpn_id, router_association):
-        with db_api.context_manager.writer.using(context):
+        with db_api.CONTEXT_WRITER.using(context):
             assoc = self.bgpvpn_db.create_router_assoc(context, bgpvpn_id,
                                                        router_association)
             self.create_router_assoc_precommit(context, assoc)
@@ -182,7 +179,7 @@ class BGPVPNDriverDBMixin(BGPVPNDriverBase):
                                                 filters, fields)
 
     def delete_router_assoc(self, context, assoc_id, bgpvpn_id):
-        with db_api.context_manager.writer.using(context):
+        with db_api.CONTEXT_WRITER.using(context):
             router_assoc = self.bgpvpn_db.get_router_assoc(context,
                                                            assoc_id,
                                                            bgpvpn_id)
@@ -299,16 +296,12 @@ class BGPVPNDriver(BGPVPNDriverDBMixin):
         pass
 
 
-@six.add_metaclass(abc.ABCMeta)
-class BGPVPNDriverRCBase(BGPVPNDriverBase):
+class BGPVPNDriverRCBase(BGPVPNDriverBase, metaclass=abc.ABCMeta):
     """Base class for drivers implementing the bgpvpn-routes-control API ext"""
 
     more_supported_extension_aliases = [
         bgpvpn_rc.Bgpvpn_routes_control.get_alias()]
 
-    def __init__(self, *args, **kwargs):
-        super(BGPVPNDriverRCBase, self).__init__(*args, **kwargs)
-
     @abc.abstractmethod
     def update_router_assoc(self, context, assoc_id, router_association):
         pass
@@ -334,8 +327,8 @@ class BGPVPNDriverRCBase(BGPVPNDriverBase):
         pass
 
 
-@six.add_metaclass(abc.ABCMeta)
-class BGPVPNDriverRCDBMixin(BGPVPNDriverRCBase, BGPVPNDriverDBMixin):
+class BGPVPNDriverRCDBMixin(BGPVPNDriverRCBase, BGPVPNDriverDBMixin,
+                            metaclass=abc.ABCMeta):
     """BGPVPNDriverDBMixin with DB operations for bgpvpn-route-control ext."""
 
     def __init__(self, *args, **xargs):
@@ -343,7 +336,7 @@ class BGPVPNDriverRCDBMixin(BGPVPNDriverRCBase, BGPVPNDriverDBMixin):
 
     def update_router_assoc(self, context, assoc_id, bgpvpn_id, router_assoc):
         old_router_assoc = self.get_router_assoc(context, assoc_id, bgpvpn_id)
-        with db_api.context_manager.writer.using(context):
+        with db_api.CONTEXT_WRITER.using(context):
             router_assoc = self.bgpvpn_db.update_router_assoc(context,
                                                               assoc_id,
                                                               bgpvpn_id,
@@ -365,7 +358,7 @@ class BGPVPNDriverRCDBMixin(BGPVPNDriverRCBase, BGPVPNDriverDBMixin):
         pass
 
     def create_port_assoc(self, context, bgpvpn_id, port_association):
-        with db_api.context_manager.writer.using(context):
+        with db_api.CONTEXT_WRITER.using(context):
             port_assoc = self.bgpvpn_db.create_port_assoc(context, bgpvpn_id,
                                                           port_association)
             self.create_port_assoc_precommit(context, port_assoc)
@@ -390,7 +383,7 @@ class BGPVPNDriverRCDBMixin(BGPVPNDriverRCBase, BGPVPNDriverDBMixin):
 
     def update_port_assoc(self, context, assoc_id, bgpvpn_id, port_assoc):
         old_port_assoc = self.get_port_assoc(context, assoc_id, bgpvpn_id)
-        with db_api.context_manager.writer.using(context):
+        with db_api.CONTEXT_WRITER.using(context):
             port_assoc = self.bgpvpn_db.update_port_assoc(context, assoc_id,
                                                           bgpvpn_id,
                                                           port_assoc)
@@ -411,7 +404,7 @@ class BGPVPNDriverRCDBMixin(BGPVPNDriverRCBase, BGPVPNDriverDBMixin):
         pass
 
     def delete_port_assoc(self, context, assoc_id, bgpvpn_id):
-        with db_api.context_manager.writer.using(context):
+        with db_api.CONTEXT_WRITER.using(context):
             port_assoc = self.bgpvpn_db.get_port_assoc(context,
                                                        assoc_id,
                                                        bgpvpn_id)
