@@ -12,7 +12,10 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-from neutron import context
+
+from neutron_lib.api.definitions import bgpvpn_routes_control as bgpvpn_rc_def
+from neutron_lib.api.definitions import bgpvpn_vni as bgpvpn_vni_def
+from neutron_lib import context
 
 from networking_bgpvpn.neutron.db.bgpvpn_db import BGPVPNPluginDb
 from networking_bgpvpn.neutron.extensions.bgpvpn \
@@ -20,6 +23,7 @@ from networking_bgpvpn.neutron.extensions.bgpvpn \
 from networking_bgpvpn.neutron.extensions.bgpvpn import BGPVPNNetAssocNotFound
 from networking_bgpvpn.neutron.extensions.bgpvpn import BGPVPNNotFound
 from networking_bgpvpn.neutron.services.common import constants
+from networking_bgpvpn.neutron.services.common import utils
 from networking_bgpvpn.tests.unit.services import test_plugin
 
 
@@ -29,8 +33,8 @@ def _id_list(list):
 
 class BgpvpnDBTestCase(test_plugin.BgpvpnTestCaseMixin):
 
-    def setUp(self):
-        super(BgpvpnDBTestCase, self).setUp()
+    def setUp(self, service_provider=None):
+        super(BgpvpnDBTestCase, self).setUp(service_provider)
         self.ctx = context.get_admin_context()
         self.plugin_db = BGPVPNPluginDb()
 
@@ -45,7 +49,9 @@ class BgpvpnDBTestCase(test_plugin.BgpvpnTestCaseMixin):
                  "route_targets": ["64512:1"],
                  "import_targets": ["64512:11", "64512:12"],
                  "export_targets": ["64512:13", "64512:14"],
-                 "route_distinguishers": ["64512:15", "64512:16"]
+                 "route_distinguishers": ["64512:15", "64512:16"],
+                 "vni": "1000",
+                 "local_pref": "777"
                  }
             )
 
@@ -68,6 +74,27 @@ class BgpvpnDBTestCase(test_plugin.BgpvpnTestCaseMixin):
                              bgpvpn['export_targets'])
             self.assertEqual(["64512:15", "64512:16"],
                              bgpvpn['route_distinguishers'])
+
+            if utils.is_extension_supported(self.bgpvpn_plugin,
+                                            bgpvpn_vni_def.ALIAS):
+                self.assertEqual(1000, bgpvpn['vni'])
+            else:
+                #
+                # Test should ensure vni attribute is not present as
+                # bpvpn_vni extension is not loaded.
+                #
+                self.assertNotIn('vni', bgpvpn)
+
+            if utils.is_extension_supported(self.bgpvpn_plugin,
+                                            bgpvpn_rc_def.ALIAS):
+                self.assertEqual(777, bgpvpn['local_pref'])
+            else:
+                #
+                # Test should ensure local_pref attribute is not present as
+                # bpvpn-routes-control extension is not loaded.
+                #
+                self.assertNotIn('local_pref', bgpvpn)
+
             self.assertEqual([net['network']['id']], bgpvpn['networks'])
 
             assoc1 = self.plugin_db.get_net_assoc(self.ctx, assoc1['id'],
@@ -101,7 +128,8 @@ class BgpvpnDBTestCase(test_plugin.BgpvpnTestCaseMixin):
                  "tenant_id": "a-b-c-d",
                  "route_targets": [],
                  "import_targets": ["64512:22"],
-                 "route_distinguishers": []
+                 "route_distinguishers": [],
+                 "local_pref": "100"
                  })
 
             # retrieve
@@ -115,7 +143,7 @@ class BgpvpnDBTestCase(test_plugin.BgpvpnTestCaseMixin):
             self.assertEqual(["64512:13", "64512:14"],
                              bgpvpn2['export_targets'])
             self.assertEqual([], bgpvpn2['route_distinguishers'])
-
+            self.assertEqual(100, bgpvpn2['local_pref'])
             # find bgpvpn by network_id
             bgpvpn3 = self.plugin_db.get_bgpvpns(
                 self.ctx,
@@ -386,3 +414,85 @@ class BgpvpnDBTestCase(test_plugin.BgpvpnTestCaseMixin):
             self.assertNotIn(bgpvpn1['bgpvpn']['id'], bgpvpn_id_list)
             self.assertIn(bgpvpn2['bgpvpn']['id'], bgpvpn_id_list)
             self.assertNotIn(bgpvpn3['bgpvpn']['id'], bgpvpn_id_list)
+
+    def test_db_associate_disassociate_port(self):
+        with self.port(tenant_id=self._tenant_id) as port, \
+                self.bgpvpn() as bgpvpn:
+            port_id = port['port']['id']
+            bgpvpn_id = bgpvpn['bgpvpn']['id']
+            with self.assoc_port(bgpvpn_id, port_id):
+                bgpvpn = self.plugin_db.get_bgpvpn(self.ctx, bgpvpn_id)
+                self.assertEqual([port_id], bgpvpn['ports'])
+            bgpvpn = self.plugin_db.get_bgpvpn(self.ctx, bgpvpn_id)
+            self.assertEqual([], bgpvpn['ports'])
+
+    def test_db_update_port_association(self):
+        ROUTE_A = {'type': 'prefix',
+                   'prefix': '12.1.0.0/16'}
+        ROUTE_B = {'type': 'prefix',
+                   'prefix': '14.0.0.0/8',
+                   'local_pref': 200}
+        ROUTE_Bbis = {'type': 'prefix',
+                      'prefix': '14.0.0.0/8',
+                      'local_pref': 100}
+        ROUTE_C = {'type': 'prefix',
+                   'prefix': '18.1.0.0/16'}
+
+        def with_defaults(port_assoc_route):
+            r = dict(local_pref=None)
+            r.update(port_assoc_route)
+            return r
+
+        with self.network() as net, \
+                self.subnet(network={'network': net['network']}) as subnet, \
+                self.port(subnet={'subnet': subnet['subnet']}) as port, \
+                self.bgpvpn() as bgpvpn, \
+                self.assoc_port(bgpvpn['bgpvpn']['id'],
+                                port['port']['id'],
+                                advertise_fixed_ips=False,
+                                routes=[ROUTE_A, ROUTE_B]) as port_assoc:
+            bgpvpn_id = bgpvpn['bgpvpn']['id']
+
+            self._update('bgpvpn/bgpvpns/%s/port_associations' % bgpvpn_id,
+                         port_assoc['port_association']['id'],
+                         {'port_association': {'advertise_fixed_ips': True,
+                                               'routes': [ROUTE_Bbis, ROUTE_C]}
+                          })
+
+            assoc = self.show_port_assoc(
+                bgpvpn['bgpvpn']['id'],
+                port_assoc['port_association']['id'])
+            assoc = assoc['port_association']
+
+            self.assertTrue(assoc['advertise_fixed_ips'])
+            self.assertNotIn(with_defaults(ROUTE_A),
+                             assoc['routes'])
+            self.assertIn(with_defaults(ROUTE_Bbis),
+                          assoc['routes'])
+            self.assertIn(with_defaults(ROUTE_C),
+                          assoc['routes'])
+
+            res = self._update(
+                'bgpvpn/bgpvpns/%s/port_associations' % bgpvpn_id,
+                port_assoc['port_association']['id'],
+                {'port_association': {'routes': []}}
+            )
+            self.assertEqual(0, len(res['port_association']['routes']))
+
+
+class BgpvpnDBTestCaseWithVNI(BgpvpnDBTestCase):
+
+    def setUp(self):
+        test_service_provider = ('networking_bgpvpn.tests.unit.services'
+                                 '.test_plugin.TestBgpvpnDriverWithVni')
+        super(BgpvpnDBTestCaseWithVNI, self).setUp(
+            service_provider=test_service_provider)
+
+
+class BgpvpnDBTestCaseWithRC(BgpvpnDBTestCase):
+
+    def setUp(self):
+        test_service_provider = ('networking_bgpvpn.neutron.services.'
+                                 'service_drivers.driver_api.BGPVPNDriverRC')
+        super(BgpvpnDBTestCaseWithRC, self).setUp(
+            service_provider=test_service_provider)
