@@ -15,7 +15,8 @@
 
 import contextlib
 import copy
-import mock
+from unittest import mock
+
 import webob.exc
 
 from neutron_lib.plugins import directory
@@ -24,6 +25,7 @@ from oslo_utils import uuidutils
 from neutron.api import extensions as api_extensions
 from neutron.db import servicetype_db as sdb
 from neutron import extensions as n_extensions
+from neutron.services import provider_configuration as pconfig
 from neutron.tests.unit.db import test_db_base_plugin_v2
 from neutron.tests.unit.extensions import test_l3
 from neutron.tests.unit.extensions.test_l3 import TestL3NatServicePlugin
@@ -48,8 +50,8 @@ def http_client_error(req, res):
 
 class TestBgpvpnDriverWithVni(driver_api.BGPVPNDriverRC):
     more_supported_extension_aliases = (
-        driver_api.BGPVPNDriverRC.more_supported_extension_aliases +
-        [bgpvpn_vni_def.ALIAS])
+        driver_api.BGPVPNDriverRC.more_supported_extension_aliases + [
+            bgpvpn_vni_def.ALIAS])
 
     def __init__(self, *args, **kwargs):
         super(TestBgpvpnDriverWithVni, self).__init__(*args, **kwargs)
@@ -60,11 +62,11 @@ class BgpvpnTestCaseMixin(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
 
     def setUp(self, service_provider=None, core_plugin=None):
         if not service_provider:
-            provider = (bgpvpn_def.LABEL +
+            provider = (bgpvpn_def.ALIAS +
                         ':dummy:networking_bgpvpn.neutron.services.'
                         'service_drivers.driver_api.BGPVPNDriverRC:default')
         else:
-            provider = (bgpvpn_def.LABEL + ':test:' + service_provider +
+            provider = (bgpvpn_def.ALIAS + ':test:' + service_provider +
                         ':default')
 
         bits = provider.split(':')
@@ -81,6 +83,11 @@ class BgpvpnTestCaseMixin(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
                               'get_service_providers').start())
         self.service_providers.return_value = [provider]
 
+        self.provider_configuration = (
+            mock.patch.object(pconfig.ProviderConfiguration,
+                              '__init__').start())
+        self.provider_configuration.return_value = None
+
         bgpvpn_plugin_str = ('networking_bgpvpn.neutron.services.plugin.'
                              'BGPVPNPlugin')
         l3_plugin_str = ('neutron.tests.unit.extensions.test_l3.'
@@ -95,7 +102,7 @@ class BgpvpnTestCaseMixin(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
         # of the plugin
         ext_mgr = api_extensions.PluginAwareExtensionManager(
             extensions_path,
-            {bgpvpn_def.LABEL: plugin.BGPVPNPlugin(),
+            {bgpvpn_def.ALIAS: plugin.BGPVPNPlugin(),
              'l3_plugin_name': TestL3NatServicePlugin()})
 
         super(BgpvpnTestCaseMixin, self).setUp(
@@ -105,7 +112,7 @@ class BgpvpnTestCaseMixin(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
 
         # find the BGPVPN plugin that was instantiated by the
         # extension manager:
-        self.bgpvpn_plugin = directory.get_plugin(bgpvpn_def.LABEL)
+        self.bgpvpn_plugin = directory.get_plugin(bgpvpn_def.ALIAS)
 
         self.bgpvpn_data = {'bgpvpn': {'name': 'bgpvpn1',
                                        'type': 'l3',
@@ -132,7 +139,7 @@ class BgpvpnTestCaseMixin(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
         else:
             req_data['bgpvpn'].update(kwargs)
         req = self.new_create_request(
-            'bgpvpn/bgpvpns', req_data, fmt=fmt)
+            'bgpvpn/bgpvpns', req_data, fmt=fmt, as_admin=True)
         res = req.get_response(self.ext_api)
         if res.status_int >= 400:
             raise http_client_error(req, res)
@@ -140,7 +147,7 @@ class BgpvpnTestCaseMixin(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
         yield bgpvpn
         if do_delete:
             self._delete('bgpvpn/bgpvpns',
-                         bgpvpn['bgpvpn']['id'])
+                         bgpvpn['bgpvpn']['id'], as_admin=True)
 
     @contextlib.contextmanager
     def assoc_net(self, bgpvpn_id, net_id, do_disassociate=True):
@@ -152,7 +159,8 @@ class BgpvpnTestCaseMixin(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
             data=data,
             fmt=fmt,
             id=bgpvpn_id,
-            subresource='network_associations')
+            subresource='network_associations',
+            as_admin=True)
         res = req.get_response(self.ext_api)
         if res.status_int >= 400:
             raise http_client_error(req, res)
@@ -164,7 +172,8 @@ class BgpvpnTestCaseMixin(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
                 bgpvpn_id,
                 fmt=self.fmt,
                 subresource='network_associations',
-                sub_id=assoc['network_association']['id'])
+                sub_id=assoc['network_association']['id'],
+                as_admin=True)
             res = del_req.get_response(self.ext_api)
             if res.status_int >= 400:
                 raise http_client_error(del_req, res)
@@ -179,7 +188,8 @@ class BgpvpnTestCaseMixin(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
             data=data,
             fmt=fmt,
             id=bgpvpn_id,
-            subresource='router_associations')
+            subresource='router_associations',
+            as_admin=True)
         res = req.get_response(self.ext_api)
         if res.status_int >= 400:
             raise http_client_error(req, res)
@@ -191,7 +201,8 @@ class BgpvpnTestCaseMixin(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
                 bgpvpn_id,
                 fmt=self.fmt,
                 subresource='router_associations',
-                sub_id=assoc['router_association']['id'])
+                sub_id=assoc['router_association']['id'],
+                as_admin=True)
             res = del_req.get_response(self.ext_api)
             if res.status_int >= 400:
                 raise http_client_error(del_req, res)
@@ -207,7 +218,8 @@ class BgpvpnTestCaseMixin(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
             data=data,
             fmt=fmt,
             id=bgpvpn_id,
-            subresource='port_associations')
+            subresource='port_associations',
+            as_admin=True)
         res = req.get_response(self.ext_api)
         if res.status_int >= 400:
             raise http_client_error(req, res)
@@ -219,7 +231,8 @@ class BgpvpnTestCaseMixin(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
                 bgpvpn_id,
                 fmt=self.fmt,
                 subresource='port_associations',
-                sub_id=assoc['port_association']['id'])
+                sub_id=assoc['port_association']['id'],
+                as_admin=True)
             res = del_req.get_response(self.ext_api)
             if res.status_int >= 400:
                 raise http_client_error(del_req, res)
@@ -287,7 +300,8 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                     data=data,
                     fmt=self.fmt,
                     id=id,
-                    subresource='network_associations')
+                    subresource='network_associations',
+                    as_admin=True)
                 res = bgpvpn_net_req.get_response(self.ext_api)
                 self.assertEqual(res.status_int, webob.exc.HTTPForbidden.code)
 
@@ -303,12 +317,13 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                     data=data,
                     fmt=self.fmt,
                     id=id,
-                    subresource='network_associations')
+                    subresource='network_associations',
+                    as_admin=True)
                 res = bgpvpn_net_req.get_response(self.ext_api)
                 self.assertEqual(res.status_int, webob.exc.HTTPForbidden.code)
 
     def test_bgpvpn_router_assoc_create(self):
-        with self.router(tenant_id=self._tenant_id) as router,\
+        with self.router(tenant_id=self._tenant_id) as router, \
                 self.bgpvpn() as bgpvpn, \
                 mock.patch.object(
                     self.bgpvpn_plugin,
@@ -335,7 +350,8 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                                    bgpvpn_id,
                                    router_assoc['router_association']['id'],
                                    {'router_association':
-                                       {'advertise_extra_routes': False}}
+                                       {'advertise_extra_routes': False}},
+                                   as_admin=True
                                    )
             expected = {'router_association': {
                 'id': router_assoc['router_association']['id'],
@@ -355,7 +371,8 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                 data=data,
                 fmt=self.fmt,
                 id=id,
-                subresource='router_associations')
+                subresource='router_associations',
+                as_admin=True)
             res = bgpvpn_router_req.get_response(self.ext_api)
             self.assertEqual(res.status_int, webob.exc.HTTPBadRequest.code)
 
@@ -370,7 +387,8 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                 data=data,
                 fmt=self.fmt,
                 id=id,
-                subresource='router_associations')
+                subresource='router_associations',
+                as_admin=True)
             res = bgpvpn_router_req.get_response(self.ext_api)
             self.assertEqual(res.status_int, webob.exc.HTTPNotFound.code)
 
@@ -386,7 +404,8 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                     data=data,
                     fmt=self.fmt,
                     id=id,
-                    subresource='router_associations')
+                    subresource='router_associations',
+                    as_admin=True)
                 res = bgpvpn_router_req.get_response(self.ext_api)
                 self.assertEqual(res.status_int, webob.exc.HTTPForbidden.code)
 
@@ -403,7 +422,8 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                     data=data,
                     fmt=self.fmt,
                     id=id,
-                    subresource='router_associations')
+                    subresource='router_associations',
+                    as_admin=True)
                 res = bgpvpn_router_req.get_response(self.ext_api)
                 self.assertEqual(res.status_int, webob.exc.HTTPBadRequest.code)
 
@@ -419,12 +439,13 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                     data=data,
                     fmt=self.fmt,
                     id=id,
-                    subresource='router_associations')
+                    subresource='router_associations',
+                    as_admin=True)
                 res = bgpvpn_router_req.get_response(self.ext_api)
                 self.assertEqual(res.status_int, webob.exc.HTTPForbidden.code)
 
     def test_router_net_combination(self):
-        with self.network() as net,\
+        with self.network() as net, \
                 self.bgpvpn() as bgpvpn, \
                 self.router(tenant_id=self._tenant_id) as router:
             self._test_router_net_combination_validation(
@@ -462,7 +483,8 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                 data=data,
                 fmt=self.fmt,
                 id=router['id'],
-                subresource='add_router_interface')
+                subresource='add_router_interface',
+                as_admin=True)
             res = bgpvpn_rtr_intf_req.get_response(self.ext_api)
             if res.status_int >= 400:
                 raise http_client_error(bgpvpn_rtr_intf_req, res)
@@ -502,7 +524,8 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                 data=data,
                 fmt=self.fmt,
                 id=router['id'],
-                subresource='add_router_interface')
+                subresource='add_router_interface',
+                as_admin=True)
             res = bgpvpn_rtr_intf_req.get_response(self.ext_api)
             if res.status_int >= 400:
                 raise http_client_error(bgpvpn_rtr_intf_req, res)
@@ -519,11 +542,11 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
             self.assertEqual(res.status_int, webob.exc.HTTPBadRequest.code)
 
     def test_attach_subnet_to_router_both_attached_to_bgpvpn(self):
-        with self.network() as net,\
-                self.bgpvpn() as bgpvpn,\
-                self.router(tenant_id=self._tenant_id) as router,\
-                self.subnet(network={'network': net['network']}) as subnet,\
-                self.assoc_net(bgpvpn['bgpvpn']['id'], net['network']['id']),\
+        with self.network() as net, \
+                self.bgpvpn() as bgpvpn, \
+                self.router(tenant_id=self._tenant_id) as router, \
+                self.subnet(network={'network': net['network']}) as subnet, \
+                self.assoc_net(bgpvpn['bgpvpn']['id'], net['network']['id']), \
                 self.assoc_router(bgpvpn['bgpvpn']['id'],
                                   router['router']['id']):
             # Attach subnet to router
@@ -533,17 +556,18 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                 data=data,
                 fmt=self.fmt,
                 id=router['router']['id'],
-                subresource='add_router_interface')
+                subresource='add_router_interface',
+                as_admin=True)
             res = bgpvpn_rtr_intf_req.get_response(self.ext_api)
             self.assertEqual(res.status_int, webob.exc.HTTPConflict.code)
 
     def test_attach_port_to_router_both_attached_to_bgpvpn(self):
-        with self.network() as net,\
-                self.bgpvpn() as bgpvpn,\
-                self.router(tenant_id=self._tenant_id) as router,\
-                self.subnet(network={'network': net['network']}) as subnet,\
-                self.port(subnet={'subnet': subnet['subnet']}) as port,\
-                self.assoc_net(bgpvpn['bgpvpn']['id'], net['network']['id']),\
+        with self.network() as net, \
+                self.bgpvpn() as bgpvpn, \
+                self.router(tenant_id=self._tenant_id) as router, \
+                self.subnet(network={'network': net['network']}) as subnet, \
+                self.port(subnet={'subnet': subnet['subnet']}) as port, \
+                self.assoc_net(bgpvpn['bgpvpn']['id'], net['network']['id']), \
                 self.assoc_router(bgpvpn['bgpvpn']['id'],
                                   router['router']['id']):
             # Attach subnet to router
@@ -553,7 +577,8 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                 data=data,
                 fmt=self.fmt,
                 id=router['router']['id'],
-                subresource='add_router_interface')
+                subresource='add_router_interface',
+                as_admin=True)
             res = bgpvpn_rtr_intf_req.get_response(self.ext_api)
             self.assertEqual(res.status_int, webob.exc.HTTPConflict.code)
 
@@ -574,7 +599,7 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                                 routes=[{
                                     'type': 'prefix',
                                     'prefix': '12.1.3.0/24',
-                                    }]):
+                                }]):
             mock_validate.assert_called_once_with(
                 mock.ANY, port['port']['id'])
 
@@ -594,7 +619,8 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                 data=data,
                 fmt=self.fmt,
                 id=bgpvpn['bgpvpn']['id'],
-                subresource='port_associations')
+                subresource='port_associations',
+                as_admin=True)
             res = bgpvpn_net_req.get_response(self.ext_api)
             self.assertEqual(res.status_int, webob.exc.HTTPBadRequest.code)
             return res.body
@@ -611,8 +637,7 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                     'routes': [{
                         'type': 'bgpvpn',
                         'bgpvpn_id': '3aff9b6b-387b-4ffd-a9ff-a4bdffb349ff'
-                        }]
-                    }}
+                    }]}}
 
             bgpvpn_net_req = self.new_create_request(
                 'bgpvpn/bgpvpns',
@@ -638,15 +663,15 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                     'routes': [{
                         'type': 'bgpvpn',
                         'bgpvpn_id': bgpvpn_other['bgpvpn']['id']
-                        }]
-                    }}
+                    }]}}
 
             bgpvpn_net_req = self.new_create_request(
                 'bgpvpn/bgpvpns',
                 data=data,
                 fmt=self.fmt,
                 id=bgpvpn['bgpvpn']['id'],
-                subresource='port_associations')
+                subresource='port_associations',
+                as_admin=True)
             res = bgpvpn_net_req.get_response(self.ext_api)
             self.assertEqual(res.status_int, webob.exc.HTTPBadRequest.code)
             self.assertIn("bgpvpn specified in route does not belong to "
@@ -693,7 +718,8 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                     data=data,
                     fmt=self.fmt,
                     id=id,
-                    subresource='port_associations')
+                    subresource='port_associations',
+                    as_admin=True)
                 res = bgpvpn_port_req.get_response(self.ext_api)
                 self.assertEqual(res.status_int, webob.exc.HTTPForbidden.code)
 
@@ -709,7 +735,8 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                     data=data,
                     fmt=self.fmt,
                     id=id,
-                    subresource='port_associations')
+                    subresource='port_associations',
+                    as_admin=True)
                 res = bgpvpn_port_req.get_response(self.ext_api)
                 self.assertEqual(res.status_int, webob.exc.HTTPForbidden.code)
 
@@ -728,7 +755,8 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
 
             self._update('bgpvpn/bgpvpns/%s/port_associations' % bgpvpn_id,
                          port_assoc['port_association']['id'],
-                         {'port_association': {'advertise_fixed_ips': False}}
+                         {'port_association': {'advertise_fixed_ips': False}},
+                         as_admin=True
                          )
 
             # one call for create, one call for update
@@ -751,10 +779,10 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                     'routes': [{
                         'type': 'bgpvpn',
                         'bgpvpn_id': bgpvpn_other['bgpvpn']['id']
-                        }]
-                    }
-                 },
-                port_assoc['port_association']['id']
+                    }]
+                }},
+                port_assoc['port_association']['id'],
+                as_admin=True
             )
 
             res = req.get_response(self.ext_api)
@@ -764,6 +792,35 @@ class TestBGPVPNServicePlugin(BgpvpnTestCaseMixin):
                 "bgpvpn specified in route does not belong to the tenant",
                 str(res.body))
 
+    def test_bgpvpn_port_assoc_update_bgpvpn_route_wrong_type(self):
+        with self.network() as net, \
+                self.subnet(network={'network': net['network']}) as subnet, \
+                self.port(subnet={'subnet': subnet['subnet']}) as port, \
+                self.bgpvpn(type='l2') as bgpvpn_l2, \
+                self.bgpvpn(type='l3') as bgpvpn_l3, \
+                self.assoc_port(bgpvpn_l2['bgpvpn']['id'],
+                                port['port']['id']) as port_assoc:
+
+            bgpvpn_id = bgpvpn_l2['bgpvpn']['id']
+
+            req = self.new_update_request(
+                'bgpvpn/bgpvpns/%s/port_associations' % bgpvpn_id,
+                {'port_association': {
+                    'routes': [{
+                        'type': 'bgpvpn',
+                        'bgpvpn_id': bgpvpn_l3['bgpvpn']['id']
+                    }]
+                }},
+                port_assoc['port_association']['id'],
+                as_admin=True
+            )
+
+            res = req.get_response(self.ext_api)
+
+            self.assertEqual(res.status_int, webob.exc.HTTPBadRequest.code)
+            self.assertIn("differing from type of associated BGPVPN",
+                          str(res.body))
+
 
 class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
 
@@ -771,8 +828,7 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
         super(TestBGPVPNServiceDriverDB, self).setUp()
 
     def _raise_bgpvpn_driver_precommit_exc(self, *args, **kwargs):
-            raise extensions.bgpvpn.BGPVPNDriverError(
-                method='precommit method')
+        raise extensions.bgpvpn.BGPVPNDriverError(method='precommit method')
 
     @mock.patch.object(driver_api.BGPVPNDriver,
                        'create_bgpvpn_postcommit')
@@ -799,7 +855,7 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
                                new=self._raise_bgpvpn_driver_precommit_exc):
             # Assert that an error is returned to the client
             bgpvpn_req = self.new_create_request(
-                'bgpvpn/bgpvpns', self.bgpvpn_data)
+                'bgpvpn/bgpvpns', self.bgpvpn_data, as_admin=True)
             res = bgpvpn_req.get_response(self.ext_api)
             self.assertEqual(webob.exc.HTTPError.code,
                              res.status_int)
@@ -817,12 +873,19 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
                                   'delete_bgpvpn_precommit',
                                   new=self._raise_bgpvpn_driver_precommit_exc):
             bgpvpn_req = self.new_delete_request('bgpvpn/bgpvpns',
-                                                 bgpvpn['bgpvpn']['id'])
+                                                 bgpvpn['bgpvpn']['id'],
+                                                 as_admin=True)
             res = bgpvpn_req.get_response(self.ext_api)
             self.assertEqual(webob.exc.HTTPError.code,
                              res.status_int)
             # Assert that existing bgpvpn remains
             list = self._list('bgpvpn/bgpvpns', fmt='json')
+            bgpvpn['bgpvpn'].pop('import_targets')
+            bgpvpn['bgpvpn'].pop('project_id')
+            bgpvpn['bgpvpn'].pop('tenant_id')
+            bgpvpn['bgpvpn'].pop('route_distinguishers')
+            bgpvpn['bgpvpn'].pop('route_targets')
+            bgpvpn['bgpvpn'].pop('export_targets')
             self.assertEqual([bgpvpn['bgpvpn']], list['bgpvpns'])
 
     @mock.patch.object(driver_api.BGPVPNDriver,
@@ -834,7 +897,7 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
                 mock.patch.object(bgpvpn_db.BGPVPNPluginDb, 'get_bgpvpn',
                                   return_value=self.converted_data):
             self._delete('bgpvpn/bgpvpns',
-                         bgpvpn['bgpvpn']['id'])
+                         bgpvpn['bgpvpn']['id'], as_admin=True)
             mock_delete_db.assert_called_once_with(mock.ANY,
                                                    bgpvpn['bgpvpn']['id'])
             mock_delete_postcommit.assert_called_once_with(mock.ANY,
@@ -843,7 +906,8 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
     @mock.patch.object(bgpvpn_db.BGPVPNPluginDb, 'get_bgpvpn')
     def test_get_bgpvpn(self, mock_get_db):
         with self.bgpvpn() as bgpvpn:
-            self._show('bgpvpn/bgpvpns', bgpvpn['bgpvpn']['id'])
+            self._show('bgpvpn/bgpvpns', bgpvpn['bgpvpn']['id'],
+                       as_admin=True)
             mock_get_db.assert_called_once_with(mock.ANY,
                                                 bgpvpn['bgpvpn']['id'],
                                                 mock.ANY)
@@ -893,7 +957,7 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
             data = {"bgpvpn": {"name": new_bgpvpn['name']}}
             self._update('bgpvpn/bgpvpns',
                          bgpvpn['bgpvpn']['id'],
-                         data)
+                         data, as_admin=True)
 
             mock_update_db.assert_called_once_with(
                 mock.ANY, bgpvpn['bgpvpn']['id'], data['bgpvpn'])
@@ -911,7 +975,8 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
             self._update('bgpvpn/bgpvpns',
                          bgpvpn['bgpvpn']['id'],
                          new_data,
-                         expected_code=webob.exc.HTTPError.code)
+                         expected_code=webob.exc.HTTPError.code,
+                         as_admin=True)
             show_bgpvpn = self._show('bgpvpn/bgpvpns',
                                      bgpvpn['bgpvpn']['id'])
             self.assertEqual(self.bgpvpn_data['bgpvpn']['name'],
@@ -963,7 +1028,8 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
                 data=data,
                 fmt=fmt,
                 id=bgpvpn['bgpvpn']['id'],
-                subresource='network_associations')
+                subresource='network_associations',
+                as_admin=True)
             res = bgpvpn_net_req.get_response(self.ext_api)
             # Assert that driver failure returns an error
             self.assertEqual(webob.exc.HTTPError.code,
@@ -983,7 +1049,7 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
                     assoc_id = assoc['network_association']['id']
                     res = 'bgpvpn/bgpvpns/' + bgpvpn_id + \
                           '/network_associations'
-                    self._show(res, assoc_id)
+                    self._show(res, assoc_id, as_admin=True)
                     mock_get_db.assert_called_once_with(mock.ANY,
                                                         assoc_id,
                                                         bgpvpn_id,
@@ -1023,6 +1089,12 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
                     # Assert that existing bgpvpn and net-assoc remains
                     list = self._list('bgpvpn/bgpvpns', fmt='json')
                     bgpvpn['bgpvpn']['networks'] = [net_assoc['network_id']]
+                    bgpvpn['bgpvpn'].pop('import_targets')
+                    bgpvpn['bgpvpn'].pop('project_id')
+                    bgpvpn['bgpvpn'].pop('tenant_id')
+                    bgpvpn['bgpvpn'].pop('route_distinguishers')
+                    bgpvpn['bgpvpn'].pop('route_targets')
+                    bgpvpn['bgpvpn'].pop('export_targets')
                     self.assertEqual([bgpvpn['bgpvpn']], list['bgpvpns'])
 
     @mock.patch.object(driver_api.BGPVPNDriver,
@@ -1092,7 +1164,8 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
                 data=data,
                 fmt=fmt,
                 id=bgpvpn['bgpvpn']['id'],
-                subresource='router_associations')
+                subresource='router_associations',
+                as_admin=True)
             res = bgpvpn_router_req.get_response(self.ext_api)
             # Assert that driver failure returns an error
             self.assertEqual(webob.exc.HTTPError.code,
@@ -1106,13 +1179,14 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
     def test_get_bgpvpn_router_assoc(self, mock_get_db):
         with self.bgpvpn() as bgpvpn:
             bgpvpn_id = bgpvpn['bgpvpn']['id']
-            with self.router(tenant_id=self._tenant_id) as router:
+            with self.router(tenant_id=self._tenant_id,
+                             as_admin=True) as router:
                 router_id = router['router']['id']
                 with self.assoc_router(bgpvpn_id, router_id) as assoc:
                     assoc_id = assoc['router_association']['id']
                     res = 'bgpvpn/bgpvpns/' + bgpvpn_id + \
                           '/router_associations'
-                    self._show(res, assoc_id)
+                    self._show(res, assoc_id, as_admin=True)
                     mock_get_db.assert_called_once_with(mock.ANY,
                                                         assoc_id,
                                                         bgpvpn_id,
@@ -1152,6 +1226,12 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
                     # Assert that existing bgpvpn and router-assoc remains
                     list = self._list('bgpvpn/bgpvpns', fmt='json')
                     bgpvpn['bgpvpn']['routers'] = [router_assoc['router_id']]
+                    bgpvpn['bgpvpn'].pop('import_targets')
+                    bgpvpn['bgpvpn'].pop('project_id')
+                    bgpvpn['bgpvpn'].pop('tenant_id')
+                    bgpvpn['bgpvpn'].pop('route_distinguishers')
+                    bgpvpn['bgpvpn'].pop('route_targets')
+                    bgpvpn['bgpvpn'].pop('export_targets')
                     self.assertEqual([bgpvpn['bgpvpn']], list['bgpvpns'])
 
     @mock.patch.object(driver_api.BGPVPNDriver,
@@ -1188,8 +1268,8 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
                                       mock_pre_commit,
                                       mock_post_commit):
         with self.bgpvpn() as bgpvpn, \
-                self.network() as net,\
-                self.subnet(network={'network': net['network']}) as subnet,\
+                self.network() as net, \
+                self.subnet(network={'network': net['network']}) as subnet, \
                 self.port(subnet={'subnet': subnet['subnet']},
                           tenant_id=self._tenant_id) as port:
             bgpvpn_id = bgpvpn['bgpvpn']['id']
@@ -1228,7 +1308,8 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
                 data=data,
                 fmt=fmt,
                 id=bgpvpn['bgpvpn']['id'],
-                subresource='port_associations')
+                subresource='port_associations',
+                as_admin=True)
             res = bgpvpn_port_req.get_response(self.ext_api)
             # Assert that driver failure returns an error
             self.assertEqual(webob.exc.HTTPError.code,
@@ -1241,14 +1322,14 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
     @mock.patch.object(bgpvpn_db.BGPVPNPluginDb, 'get_port_assoc')
     def test_get_bgpvpn_port_assoc(self, mock_get_db):
         with self.bgpvpn() as bgpvpn, \
-                self.port(tenant_id=self._tenant_id) as port, \
+                self.port(tenant_id=self._tenant_id, is_admin=True) as port, \
                 self.assoc_port(bgpvpn['bgpvpn']['id'],
                                 port['port']['id']) as assoc:
             bgpvpn_id = bgpvpn['bgpvpn']['id']
             assoc_id = assoc['port_association']['id']
             res = 'bgpvpn/bgpvpns/' + bgpvpn_id + \
                   '/port_associations'
-            self._show(res, assoc_id)
+            self._show(res, assoc_id, as_admin=True)
             mock_get_db.assert_called_once_with(mock.ANY,
                                                 assoc_id,
                                                 bgpvpn_id,
@@ -1274,7 +1355,7 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
     def test_delete_bgpvpn_port_assoc_precommit_fails(self, mock_db_del,
                                                       mock_precommit):
         with self.bgpvpn() as bgpvpn, \
-                self.port(tenant_id=self._tenant_id) as port, \
+                self.port(tenant_id=self._tenant_id, is_admin=True) as port, \
                 self.assoc_port(bgpvpn['bgpvpn']['id'],
                                 port['port']['id']) as assoc:
             port_id = port['port']['id']
@@ -1289,6 +1370,12 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
             # Assert that existing bgpvpn and port-assoc remains
             list = self._list('bgpvpn/bgpvpns', fmt='json')
             bgpvpn['bgpvpn']['ports'] = [port_assoc['port_id']]
+            bgpvpn['bgpvpn'].pop('import_targets')
+            bgpvpn['bgpvpn'].pop('project_id')
+            bgpvpn['bgpvpn'].pop('tenant_id')
+            bgpvpn['bgpvpn'].pop('route_distinguishers')
+            bgpvpn['bgpvpn'].pop('route_targets')
+            bgpvpn['bgpvpn'].pop('export_targets')
             self.assertEqual([bgpvpn['bgpvpn']], list['bgpvpns'])
 
     @mock.patch.object(driver_api.BGPVPNDriverRC,
@@ -1317,7 +1404,7 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
             data = {"port_association": changed}
             self._update('bgpvpn/bgpvpns/%s/port_associations' % bgpvpn_id,
                          assoc['port_association']['id'],
-                         data)
+                         data, as_admin=True)
 
             mock_db_update.assert_called_once_with(mock.ANY,
                                                    assoc_id,
@@ -1327,12 +1414,12 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
                 mock.ANY,
                 assoc['port_association'],
                 new_port_assoc['port_association']
-                )
+            )
             mock_postcommit.assert_called_once_with(
                 mock.ANY,
                 assoc['port_association'],
                 new_port_assoc['port_association']
-                )
+            )
 
     @mock.patch.object(driver_api.BGPVPNDriverRC,
                        'delete_port_assoc_precommit')
